bayespy.inference.vmp.transformations.RotateMultiple.get_bound_terms
====================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateMultiple.get_bound_terms